/*
 * Copyright (c) 2008, Felix Opatz
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *  * Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *  * Neither the name of  nor the names of its contributors may be used to
 *    endorse or promote products derived from this software without specific
 *    prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 *
 * Date        Change  
 * ---------------------------------------------------------------------------
 * 2008-10-28  Initial implementation.
 */

#ifndef ZJLINK_H
#define ZJLINK_H

#ifdef WIN32

/* Handle to device as HANDLE for CreateFile */
typedef HANDLE                 HPORT;
#define INVALID_PORT_HANDLE    INVALID_HANDLE_VALUE

#else

/* Define some data types from windows.h */
#define FALSE                  0
#define TRUE                   1
typedef int                    BOOL;
typedef unsigned char          BYTE;
typedef unsigned short         WORD;
typedef unsigned long          DWORD;
typedef BYTE                   *PBYTE;
typedef WORD                   *PWORD;
typedef char                   *PCHAR;
typedef char                   *PSTR;
typedef const char             *PCSTR;
/* Handle to device as base address of UART */
typedef WORD                   HPORT;
#define INVALID_PORT_HANDLE    0xFFFF

#endif /*WIN32*/


#define DEF_COMPORT            "COM1"  /* default COM port to use          */
#define DEF_BAUDRATE           9600UL  /* default baudrate to use          */
#define DEF_MODESTRING         "8N1"   /* default mode string              */
#define BLOCK_SIZE             1024    /* size of each block transfered    */
#define MAX_FILENAME_LEN       12      /* Maximum length of filename       */
#define BAR_WIDTH              30      /* number of chars for progress bar */
#define BAR_FILLED_CHAR        178     /* char for "filled" bar parts      */
#define BAR_HOLLOW_CHAR        176     /* char for "hollow" bar parts      */
#define CHECKSUM_OK            0xFFFF  /* result of checksum compare if OK */
#define FILE_ACCEPTED          0xCC    /* file is accepted                 */
#define FILE_DECLINED          0x55    /* file is declined                 */
#define TRANS_REQUEST          0x99
#define TRANS_ACCEPTED         0x33
#define TRANS_DECLINED         0xAA


/* Functions that need to be implemented by platform specific modules */
HPORT OpenComPort(PCSTR pcszName);
BOOL ConfigureComPort(HPORT hPort, DWORD dwBaudRate, PCSTR lpszModeString);
void CloseComPort(HPORT hPort);
BYTE ReadByte(HPORT hPort);
void WriteByte(HPORT hPort, BYTE bByte);

#endif /*ZJLINK_H*/
